from ctypes import c_int

ContentType = c_int

HTTP_CONTENT_TYPE_HTML = 0
HTTP_CONTENT_TYPE_CSS = 1
HTTP_CONTENT_TYPE_JS = 2
HTTP_CONTENT_TYPE_JSON = 3
HTTP_CONTENT_TYPE_OCTET = 4
HTTP_CONTENT_TYPE_JPG = 5
HTTP_CONTENT_TYPE_PNG = 6
HTTP_CONTENT_TYPE_ICO = 7
HTTP_CONTENT_TYPE_GIF = 8
HTTP_CONTENT_TYPE_MP3 = 9
